<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE xsl:stylesheet [
	<!ENTITY nbsp "&#x00A0;">
]>
<xsl:stylesheet
	version="1.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:msxml="urn:schemas-microsoft-com:xslt"
	xmlns:umbraco.library="urn:umbraco.library"
	xmlns:CommerceLibrary="urn:CommerceLibrary"
	exclude-result-prefixes="msxml umbraco.library CommerceLibrary">


	<xsl:output method="xml" omit-xml-declaration="yes"/>

	<xsl:param name="currentPage"/>


	<xsl:template match="/">

		<!-- Check if there's any post back -->
		<xsl:variable name="isPostback" select="umbraco.library:RequestForm('quantityInput_0')"/>

		<xsl:if test="string-length($isPostback)">
			<xsl:call-template name="updateBasketTemplate"></xsl:call-template>
		</xsl:if>


		<xsl:choose>
			<xsl:when test="CommerceLibrary:HasBasket()">
				<xsl:call-template name="basketTemplate"></xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				Your basket is empty.
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template name="basketTemplate">
		<form method="post">
			<xsl:variable name="cart" select="CommerceLibrary:GetBasket()"/>
			<table>
				<tr>
					<th>Item no.</th>
					<th>Description</th>
					<th>Item price</th>
					<th>VAT</th>
					<th>Quantity</th>
					<th>Total</th>
				</tr>

				<xsl:for-each select="$cart/purchaseOrder/lineItems/lineItem">
					<tr>
						<td>
							<xsl:value-of select="@sku"/>
						</td>
						<td>
							<xsl:value-of select="@productName"/>
						</td>
						<td>
							<xsl:value-of select="CommerceLibrary:FormatCurrency(@price)"/>
						</td>
						<td>
							<xsl:value-of select="CommerceLibrary:FormatCurrency(@vat)"/>
						</td>
						<td>
							<input type="text" class="quantityInput">
								<xsl:attribute name="value">
									<xsl:value-of select="@quantity"/>
								</xsl:attribute>
								<xsl:attribute name="name">
									quantityInput_<xsl:value-of select="@index"/>
								</xsl:attribute>
							</input>
						</td>
						<td>
							<xsl:value-of select="CommerceLibrary:FormatCurrency(@total)"/>
						</td>
					</tr>
				</xsl:for-each>
				<tr>
					<td colspan="5">Sub total:</td>
					<td>
						<xsl:value-of select="CommerceLibrary:FormatCurrency($cart/purchaseOrder/@subTotal)"/>
					</td>
				</tr>
				<tr>
					<td colspan="5">VAT:</td>
					<td>
						<xsl:value-of select="CommerceLibrary:FormatCurrency($cart/purchaseOrder/@vat)"/>
					</td>
				</tr>				
				<tr>
					<td colspan="5">Order total:</td>
					<td>
						<xsl:value-of select="CommerceLibrary:FormatCurrency($cart/purchaseOrder/@orderTotal)"/>
					</td>
				</tr>
			</table>
			<input type="submit" value="Update Cart"></input> - <a href="address.aspx">Proceed to address information</a>
		</form>
	</xsl:template>

	<xsl:template name="updateBasketTemplate">
		<xsl:if test="CommerceLibrary:HasBasket()">
			<xsl:for-each select="CommerceLibrary:GetBasket()/purchaseOrder/lineItems/lineItem">
				<!-- Update highest index first in case we're deleting thus shrinking the list -->
				<xsl:sort select="@index" data-type="number" order="descending"/>

				<!-- Find the name of the posted quantity change -->
				<xsl:variable name="postedQuantity" select="umbraco.library:RequestForm(concat('quantityInput_', @index))"/>
				<xsl:variable name="result" select="CommerceLibrary:UpdateLineItem(@index, $postedQuantity)"></xsl:variable>
			</xsl:for-each>
			<xsl:variable name="pipelineResult" select="CommerceLibrary:ExecuteBasketPipeline()"></xsl:variable>
		</xsl:if>
	</xsl:template>
</xsl:stylesheet>