<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE xsl:stylesheet [ <!ENTITY nbsp "&#x00A0;"> ]>
<xsl:stylesheet 
	version="1.0" 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
	xmlns:msxml="urn:schemas-microsoft-com:xslt"
	xmlns:umbraco.library="urn:umbraco.library"
	xmlns:CommerceLibrary="urn:CommerceLibrary"
	exclude-result-prefixes="msxml umbraco.library CommerceLibrary">


<xsl:output method="xml" omit-xml-declaration="yes"/>

<xsl:param name="currentPage"/>
  <xsl:variable name="basket" select="CommerceLibrary:GetBasket()"></xsl:variable>

<xsl:template match="/">

  <xsl:apply-templates select="$basket/purchaseOrder"></xsl:apply-templates>
  
</xsl:template>

  <xsl:template match="purchaseOrder">
    <h5>Customer</h5>
    <xsl:apply-templates select="billingAddress/address"/>
    
    <h5>Shipping</h5>
    <div>
      <ul>
      <xsl:for-each select="shipments/shipment">        
        <li>
          <div>
            <xsl:value-of select="@name"/>: <xsl:value-of select="CommerceLibrary:FormatCurrency(@price)"/> <br />
            <xsl:apply-templates select="address"/>
          </div>
        </li>
      </xsl:for-each>
      </ul>
    </div>
    <h5>Payment</h5>
    <div>
      <ul>
        <xsl:for-each select="payments/payment">
          <li>
            <xsl:value-of select="@name"/> (<xsl:value-of select="@transactionId"/>)
          </li>
        </xsl:for-each>
      </ul>
    </div>
    <h5>Order Lines</h5>
    <div>
      <xsl:call-template name="lineItems"></xsl:call-template>
    </div>

    <form method="post" action="/shop/checkout/orderconfirmation.aspx">
      <!-- Something so we know that we're posting to the next page -->
      <input type="hidden" value="yes" name="submitBasket"></input>
      <input type="submit" value="Submit order"></input>
    </form>
    <div>
      <!--<a href="/shop/checkout/payment.aspx">Back</a>-->
    </div>
  </xsl:template>

  <xsl:template name="lineItems">
      <table>
        <tr>
          <th>Item no.</th>
          <th>Description</th>
          <th>Item price</th>
          <th>Quantity</th>
          <th>Total</th>
        </tr>

        <xsl:for-each select="lineItems/lineItem">
          <tr>
            <td>
              <xsl:value-of select="@sku"/>
            </td>
            <td>
              <xsl:value-of select="@productName"/>
            </td>
            <td>
              <xsl:value-of select="CommerceLibrary:FormatCurrency(@price)"/>
            </td>
            <td>
              <xsl:value-of select="@quantity"/>
            </td>
            <td>
              <xsl:value-of select="CommerceLibrary:FormatCurrency(@total)"/>
            </td>
          </tr>
        </xsl:for-each>
        <tr>
          <td colspan="4">VAT total:</td>
          <td>
            <xsl:value-of select="CommerceLibrary:FormatCurrency(@vat)"/>
          </td>
        </tr>
        <tr>
          <td colspan="4">Sub total:</td>
          <td>
            <xsl:value-of select="CommerceLibrary:FormatCurrency(@subTotal)"/>
          </td>
        </tr>
        <tr>
          <td colspan="4">Order total:</td>
          <td>
            <xsl:value-of select="CommerceLibrary:FormatCurrency(@orderTotal)"/>
          </td>
        </tr>
      </table>
  </xsl:template>
  <xsl:template match="address">
    <div>
      <xsl:value-of select="@firstName"/>&nbsp;<xsl:value-of select="@lastName"/>
    </div>
    <div>
      <xsl:value-of select="@line1"/>
    </div>
    <div>
      <xsl:value-of select="line2"/>
    </div>
    <div>
      <xsl:value-of select="@postalCode"/>&nbsp;<xsl:value-of select="@city"/>
    </div>
    <div>
      <xsl:value-of select="@country"/>
    </div>
    <div>
      E-mail:
      <xsl:value-of select="customer/@emailAddress"/>
    </div>

  </xsl:template>
</xsl:stylesheet>